==> validation-model-1.25.81-sources.jar: org/verapdf/gf/model/impl/pd/gfse/GFSEL.java <==
/**
 * This file is part of veraPDF Validation, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.gf.model.impl.pd.gfse;

import org.verapdf.gf.model.impl.pd.GFPDStructElem;
import org.verapdf.model.selayer.SEL;
import org.verapdf.pd.structure.PDStructElem;
import org.verapdf.tools.AttributeHelper;
import org.verapdf.tools.TaggedPDFConstants;

public class GFSEL extends GFPDStructElem implements SEL {

    public static final String L_STRUCTURE_ELEMENT_TYPE = "SEL";

    public GFSEL(PDStructElem structElemDictionary) {
        super(structElemDictionary, TaggedPDFConstants.L, L_STRUCTURE_ELEMENT_TYPE);
    }

    @Override
    public String getListNumbering() {
        return AttributeHelper.getListNumbering(simplePDObject);
    }

    @Override
    public Boolean getcontainsLabels() {
        for (GFPDStructElem child : getChildren()) {
            if (TaggedPDFConstants.LI.equals(child.getstandardType()) && 
                    child.getChildrenStandardTypes().contains(TaggedPDFConstants.LBL)) {
                return true;
            }
        }
        return false;
    }
}

==> validation-model-1.27.87-sources.jar: org/verapdf/gf/model/impl/pd/gfse/GFSEL.java <==
/**
 * This file is part of veraPDF Validation, a module of the veraPDF project.
 * Copyright (c) 2015-2024, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.gf.model.impl.pd.gfse;

import org.verapdf.gf.model.impl.pd.GFPDStructElem;
import org.verapdf.model.selayer.SEL;
import org.verapdf.pd.structure.PDStructElem;
import org.verapdf.tools.AttributeHelper;
import org.verapdf.tools.TaggedPDFConstants;

public class GFSEL extends GFPDStructElem implements SEL {

    public static final String L_STRUCTURE_ELEMENT_TYPE = "SEL";

    public GFSEL(PDStructElem structElemDictionary) {
        super(structElemDictionary, TaggedPDFConstants.L, L_STRUCTURE_ELEMENT_TYPE);
    }

    @Override
    public String getListNumbering() {
        return AttributeHelper.getListNumbering(simpleCOSObject);
    }

    @Override
    public Boolean getcontainsLabels() {
        for (GFPDStructElem child : getStructuralSignificanceChildren()) {
            if (TaggedPDFConstants.LI.equals(child.getstandardType()) && 
                    child.getChildrenStandardTypes().contains(TaggedPDFConstants.LBL)) {
                return true;
            }
        }
        return false;
    }
}
